/* Lepton EDA library
 * Copyright (C) 2011 gEDA Contributors
 * Copyright (C) 2020-2021 Lepton EDA Contributors
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
#include <config.h>
#include <liblepton_priv.h>

/* Used by EDA_ERROR. Returns a GQuark used to identify GErrors
 * originating in libgeda. Should not be called directly. */
GQuark
eda_error_quark (void)
{
  return g_quark_from_static_string ("eda-error-quark");
}
